@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0904';
+our $VERSION = '0.0905';
 
 use Algorithm::Combinatorics qw( combinations );
 use Math::Factor::XS qw( prime_factors );
@@ -288,7 +288,7 @@ Music::Intervals - Breakdown of musical intervals
 
 =head1 VERSION
 
-version 0.0904
+version 0.0905
 
 =head1 SYNOPSIS
 
@@ -313,7 +313,7 @@ version 0.0904
   my $ratio = $m->by_name('Eb');
   my $intervals = $m->by_description('pythagorean');
 
-  perl -Ilib -MMusic::Intervals::Ratios -E'say $Music::Intervals::Ratios::ratio->{C}{name}'
+  perl -MMusic::Intervals::Ratios -E'say $Music::Intervals::Ratios::ratio->{C}{name}'
   # unison, perfect prime, tonic
 
   # Show all the 400+ known intervals:
